==> dianara_0.9.orig.tar.gz: dianara-v0.9/src/mischelpers.h <==
/*
 *   This file is part of Dianara
 *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef MISCHELPERS_H
#define MISCHELPERS_H

#include <QObject>
#include <QString>
#include <QRegExp>
#include <QStringList>

#include <QDesktopServices> // TMP: getting avatar directory
#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
#include <QStandardPaths>
#endif

#include <QDebug>

class MiscHelpers : public QObject
{
    Q_OBJECT

public:
    explicit MiscHelpers(QObject *parent = 0);

    static QString getCachedAvatarFilename(QString url);
    static QString getCachedImageFilename(QString url);

    static QStringList htmlWithReplacedImages(QString originalHtml);
    static QString cleanHtml(QString originalHtml);

signals:

public slots:

};

#endif // MISCHELPERS_H

==> dianara-v1.0.tar.gz: dianara-v1.0/src/mischelpers.h <==
/*
 *   This file is part of Dianara
 *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef MISCHELPERS_H
#define MISCHELPERS_H

#include <QObject>
#include <QString>
#include <QRegExp>
#include <QStringList>
#include <QPixmap>
#include <QFileInfo>
#include <QTextDocument>
#include <QImageReader>

#include <QDesktopServices> // TMP: getting avatar directory
#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
#include <QStandardPaths>
#endif

#include <QDebug>

class MiscHelpers : public QObject
{
    Q_OBJECT

public:
    explicit MiscHelpers(QObject *parent = 0);

    static QString getCachedAvatarFilename(QString url);
    static QString getCachedImageFilename(QString url);

    static QString getImageContentType(QString fileURI);
    static int getImageWidth(QString fileURI);

    static QString fileSizeString(QString fileURI);

    static QStringList htmlWithReplacedImages(QString originalHtml, int postWidth);
    static QString cleanupHtml(QString originalHtml);

    static QString quotedText(QString author, QString content);

signals:

public slots:

};

#endif // MISCHELPERS_H
